document.addEventListener('DOMContentLoaded', () => {
  // Set current date
  const dateElement = document.getElementById('currentDate');
  const today = new Date();
  dateElement.textContent = today.toLocaleDateString('en-US', {
    weekday: 'long',
    year: 'numeric',
    month: 'long',
    day: 'numeric'
  });
  
  // Exercise class
  class Exercise {
    constructor(name) {
      this.name = name;
      this.sets = [];
      this.skipped = false;
    }
    
    addSet(weight, reps) {
      this.sets.push({ weight, reps });
    }
  }
  
  // State management
  const state = {
    exercises: [],
    
    addExercise(name) {
      const exercise = new Exercise(name);
      this.exercises.push(exercise);
      this.updateUI();
      this.saveToLocalStorage();
    },
    
    updateUI() {
      const container = document.getElementById('exercisesList');
      container.innerHTML = '';
      
      this.exercises.forEach((exercise, index) => {
        const exerciseElement = createExerciseElement(exercise, index);
        container.appendChild(exerciseElement);
      });
      
      updateSummary();
    },
    
    saveToLocalStorage() {
      localStorage.setItem('workoutData', JSON.stringify(this.exercises));
    },
    
    loadFromLocalStorage() {
      const data = localStorage.getItem('workoutData');
      if (data) {
        this.exercises = JSON.parse(data);
        this.updateUI();
      }
    }
  };
  
  function createExerciseElement(exercise, index) {
    const div = document.createElement('div');
    div.className = 'exercise-item';
    
    const header = document.createElement('div');
    header.className = 'exercise-header';
    header.innerHTML = `
      <span>${exercise.name}</span>
      <button class="toggle-sets">▼</button>
    `;
    
    const setsDiv = document.createElement('div');
    setsDiv.className = 'exercise-sets';
    
    // Add sets interface
    for (let i = 0; i < 3; i++) {
      const setRow = document.createElement('div');
      setRow.className = 'set-row';
      setRow.innerHTML = `
        <input type="number" placeholder="Weight (lbs)" class="weight-input">
        <input type="number" placeholder="Reps" class="reps-input">
        <span>Set ${i + 1}</span>
      `;
      setsDiv.appendChild(setRow);
    }
    
    // Add controls
    const controls = document.createElement('div');
    controls.className = 'exercise-controls';
    controls.innerHTML = `
      <button class="copy-sets">Copy to All Sets</button>
      <button class="skip-exercise">Skip Exercise</button>
    `;
    
    div.appendChild(header);
    div.appendChild(setsDiv);
    div.appendChild(controls);
    
    // Event listeners
    header.querySelector('.toggle-sets').addEventListener('click', () => {
      setsDiv.classList.toggle('active');
    });
    
    controls.querySelector('.copy-sets').addEventListener('click', () => {
      const firstWeight = setsDiv.querySelector('.weight-input').value;
      const firstReps = setsDiv.querySelector('.reps-input').value;
      
      setsDiv.querySelectorAll('.set-row').forEach(row => {
        row.querySelector('.weight-input').value = firstWeight;
        row.querySelector('.reps-input').value = firstReps;
      });
    });
    
    controls.querySelector('.skip-exercise').addEventListener('click', () => {
      exercise.skipped = true;
      div.style.opacity = '0.5';
      state.saveToLocalStorage();
      updateSummary();
    });
    
    return div;
  }
  
  function updateSummary() {
    document.getElementById('totalExercises').textContent = state.exercises.length;
    document.getElementById('completedExercises').textContent = 
      state.exercises.filter(ex => !ex.skipped).length;
  }
  
  // Add exercise button
  document.getElementById('addExercise').addEventListener('click', () => {
    const name = prompt('Enter exercise name:');
    if (name) {
      state.addExercise(name);
    }
  });
  
  // Load saved data
  state.loadFromLocalStorage();
});
